@@ -1,15 +1,18 @@
 namespace Qyoto {
 
 	using System;
+	using System.Reflection;
 	using System.Collections;
 	using System.Runtime.InteropServices;
 	using System.Text;
 
+	public delegate void EventFunc();
+
 	class EventReceiver : QObject {
 		public EventReceiver(QObject parent) : base(parent) {}
 		
 		public override bool Event(QEvent e) {
-			if (e.type() == QEvent.TypeOf.User) {
+			if (e != null && e.type() == QEvent.TypeOf.User) {
 				ThreadEvent my = e as ThreadEvent;
 				if (e != null) {
 					my.dele();
@@ -22,10 +25,10 @@ namespace Qyoto {
 	}
 
 	class ThreadEvent : QEvent {
-		public NoArgDelegate dele;
+		public EventFunc dele;
 		public GCHandle handle;
 		
-		public ThreadEvent(NoArgDelegate d) : base(QEvent.TypeOf.User) {
+		public ThreadEvent(EventFunc d) : base(QEvent.TypeOf.User) {
 			dele = d;
 		}
 	}
@@ -34,7 +37,7 @@ namespace Qyoto {
 		private EventReceiver receiver;
 		protected void SetupEventReceiver() { receiver = new EventReceiver(this); }
 
-		public static void Invoke(NoArgDelegate dele) {
+		public static void Invoke(EventFunc dele) {
 			ThreadEvent e = new ThreadEvent(dele);
 			e.handle = GCHandle.Alloc(e);  // we don't want the GC to collect the event too early
 			PostEvent(qApp.receiver, e);
@@ -44,7 +47,14 @@ namespace Qyoto {
 			CreateProxy();
 			
 			string[] args = new string[argv.Length + 1];
-			args[0] = System.Reflection.Assembly.GetExecutingAssembly().Location;
+			Assembly a = System.Reflection.Assembly.GetEntryAssembly();
+			object[] attrs = a.GetCustomAttributes(typeof(AssemblyTitleAttribute), false);
+			if (attrs.Length > 0) {
+				args[0] = ((AssemblyTitleAttribute) attrs[0]).Title;
+			} else { 
+				QFileInfo info = new QFileInfo(a.Location);
+				args[0] = info.BaseName();
+			}
 			argv.CopyTo(args, 1);
 
 			interceptor.Invoke(	"QCoreApplication$?", 
