@@ -246,12 +246,48 @@ sub writeInheritanceFile($) {
 
     } );
 
+	# Write namespaces
+	print OUT "using namespace KSVG;\n";
+	print OUT "using namespace KJS;\n\n";
+	
     # Write classInfos
     print OUT "// For all classes with generated data: the ClassInfo\n";
     Iter::LocalCompounds( $rootnode, sub {
 	my $classNode = shift;
 	my $className = join( "::", kdocAstUtil::heritage($classNode) );
 
+	# We use namespace declartions!
+	my $printName = $className;
+	$printName =~ s/KSVG:://;
+
+	# Write tagNames
+	if ($hasBridge{$className}) {
+		my $tagName = $printName;
+		$tagName =~ s/SVG//;
+		$tagName =~ s/ElementImpl//;
+
+		$tagName = lcfirst($tagName);
+
+		# Special cases, otherwise they'd be "tRef" / "tSpan" / "sVG"
+		if($printName eq "SVGTRefElementImpl" or
+		   $printName eq "SVGTSpanElementImpl" or
+		   $printName eq "SVGSVGElementImpl") {
+			$tagName =~ tr/A-Z/a-z/;
+		}
+
+		while($tagName =~ /[A-Z]/g) {
+				# Special case: color-profile instead of ie. animateColor/animateMotion
+				if($printName eq "SVGColorProfileElementImpl") {
+					$tagName = substr($tagName, 0, pos($tagName) - 1) . "-" . lc($&) . substr($tagName, pos($tagName));
+				}
+		}
+
+		# Special cases: gradient & poly aren't element! 
+		if($tagName ne "" and $tagName ne "gradient" and $tagName ne "poly") {
+			print OUT "const DOM::DOMString ${printName}::s_tagName = \"$tagName\";\n";
+		}
+	}
+
 	# Skip classes without KSVG_GENERATEDDATA
 	if (!$hasGet{$className} && !$skippedClasses{$className}) {
 	    $skippedClasses{$className} = '1' ;
@@ -263,13 +299,13 @@ sub writeInheritanceFile($) {
 	my $ok = $hasHashTable{$className};
 	print STDERR "$className has get() but no hashtable - TODO\n" if (!$ok && $hasGet{$className} eq '1');
 
-	print OUT "const KJS::ClassInfo ${className}::s_classInfo = { \"$className\", 0, ";
+	print OUT "const ClassInfo ${printName}::s_classInfo = {\"$className\",0,";
 	if ($ok) {
-	    print OUT "\&${className}::s_hashTable";
+	    print OUT "\&${printName}::s_hashTable";
 	} else {
 	    print OUT "0";
 	}
-        print OUT ", 0 };\n";
+        print OUT ",0};\n";
 	#die "problem with $className" unless defined $classinherit{$className};
 	#print OUT "const short int ${className}::s_inheritanceIndex = $classinherit{$className};\n";
     } );
@@ -281,37 +317,49 @@ sub writeInheritanceFile($) {
 	my $className = join( "::", kdocAstUtil::heritage($classNode) );
         return if ( defined $skippedClasses{$className} );
 
+	# We use namespace declartions!
+	my $printName = $className;
+	$printName =~ s/KSVG:://;
+
 	my $paramsUsed = 0;
-        print OUT "bool ${className}::hasProperty(KJS::ExecState *exec, const KJS::UString &propertyName) const\n";
-        print OUT "{\n";
+	
+	print OUT "bool ${printName}::hasProperty(ExecState *p1,const Identifier &p2) const\n";
+	print OUT "{\n";
+
 	if ($hasHashTable{$className}) {
-	    print OUT "    const KJS::HashEntry *e = KJS::Lookup::findEntry(\&${className}::s_hashTable, propertyName);\n";
-	    print OUT "    if (e)\n";
-	    print OUT "        return true;\n";
+	    print OUT "    const HashEntry *e = Lookup::findEntry(\&${printName}::s_hashTable,p2);\n";
+	    print OUT "    if(e) return true;\n";
 	    $paramsUsed=1;
 	}
 	# Now look in prototype, if it exists
 	if ( defined $hasFunctions{$className} ) {
-	    print OUT "    KJS::Object proto = " . $hasFunctions{$className} . "::self(exec);\n";
-	    print OUT "    if ( proto.hasProperty(exec,propertyName) ) {\n";
-	    print OUT "        return true;\n";
-	    print OUT "    }\n";
+
+		# We use namespace declartions!
+		my $output = $hasFunctions{$className};
+		$output =~ s/KSVG:://;
+
+	    print OUT "    Object proto = " . $output . "::self(p1);\n";
+	    print OUT "    if(proto.hasProperty(p1,p2)) return true;\n";
 	}
 	# For each direct ancestor...
 	Iter::Ancestors( $classNode, $rootnode, undef, undef, sub {
 			     my $superClassName = join( "::", kdocAstUtil::heritage($_[0]) );
+				
+				 # We use namespace declartions!
+				 my $printSuperClassName = $superClassName;
+				 $printSuperClassName =~ s/KSVG:://;
+
 			     if ( $superClassName ne '' ) { # happens with unknown parents
 			       return if ( defined $skippedClasses{$superClassName} );
-			        print OUT "    if (${superClassName}::hasProperty(exec, propertyName))\n";
-                                print OUT "        return true;\n";
+			        print OUT "    if(${printSuperClassName}::hasProperty(p1,p2)) return true;\n";
 				$paramsUsed=2;
 			     }
 		    }, undef );
-	if ($paramsUsed == 1){
-	    print OUT "    Q_UNUSED(exec);\n";
+	if ($paramsUsed == 1 && !defined $hasFunctions{$className}){
+	    print OUT "    Q_UNUSED(p1);\n";
 	}
 	if ($paramsUsed == 0){
-	    print OUT "    Q_UNUSED(exec); Q_UNUSED(propertyName);\n";
+	    print OUT "    Q_UNUSED(p1); Q_UNUSED(p2);\n";
 	}
         print OUT "    return false;\n";
         print OUT "}\n\n";
@@ -330,30 +378,40 @@ sub writeInheritanceFile($) {
 	if ($hasHashTable{$className}) {
 	    die unless $hasGet{$className};
 	    if ( $hasGet{$className} eq '1' ) {
-		print OUT "KJS::Value ${className}::get(KJS::ExecState *exec, const KJS::UString &propertyName, const KJS::ObjectImp* bridge) const\n";
+		print OUT "Value ${printName}::get(GET_METHOD_ARGS) const\n";
 		print OUT "{\n";
 		if ( defined $hasFunctions{$className} ) {
-		    print OUT "    return lookupGet<$hasFunctions{$className}Func,${className}>(exec, propertyName, &s_hashTable, this, bridge);\n";
+
+			# We use namespace declartions!
+			my $output = $hasFunctions{$className};
+			$output =~ s/KSVG:://;
+
+		    print OUT "    return lookupGet<${output}Func,${printName}>(p1,p2,&s_hashTable,this,p3);\n";
 		} else {
-		    print OUT "    return lookupGetValue<${className}>(exec, propertyName, &s_hashTable, this, bridge);\n";
+		    print OUT "    return lookupGetValue<${printName}>(p1,p2,&s_hashTable,this,p3);\n";
 		}
 		print OUT "}\n\n";
 
 		if ( defined $hasFunctions{$className} ) {
-		    my $methodName = "$hasFunctions{$className}Func::cast";
+
+			# We use namespace declartions!
+			my $output = $hasFunctions{$className};
+			$output =~ s/KSVG:://;
+
+		    my $methodName = "${output}Func::cast";
 		    my $const = 'const';
 		    # Special case - we also need that code in toNode()
-		    if ($methodName eq 'KSVG::SVGDOMNodeBridgeProtoFunc::cast') {
-			print OUT "${className} * $methodName(const KJS::ObjectImp* bridge) const\n";
+		    if ($methodName eq 'SVGDOMNodeBridgeProtoFunc::cast') {
+			print OUT "${printName} *$methodName(const ObjectImp *p1) const\n";
 			$methodName = 'KSVG::toNodeBridge';
 			print OUT "{\n";
-			print OUT "    return $methodName(bridge);\n";
+			print OUT "    return $methodName(p1);\n";
 			print OUT "}\n\n";
 			$const = '';
 		    }
 
 		    # Type resolver for the Func class
-		    print OUT "${className} * $methodName(const KJS::ObjectImp* bridge) $const\n";
+		    print OUT "${printName} *$methodName(const ObjectImp *p1) $const\n";
 		    print OUT "{\n";
 		    my @toTry;
 		    push @toTry, $classNode;
@@ -362,63 +420,79 @@ sub writeInheritanceFile($) {
 		    }
 		    foreach my $d (@toTry) {
 			my $c = join( "::", kdocAstUtil::heritage($d) );
-			print OUT "    { const KSVGBridge<$c> * test = dynamic_cast<const KSVGBridge<$c> * >(bridge);\n";
-			print OUT "    if (test) return test->impl(); }\n";
+
+			# We use namespace declartions!
+			my $d = $c;
+			$d =~ s/KSVG:://;
+			
+			print OUT "    { const KSVGBridge<$d> *test = dynamic_cast<const KSVGBridge<$d> * >(p1);\n";
+			print OUT "    if(test) return test->impl(); }\n";
 		    }
-		    print OUT "    return 0L;\n";
+		    print OUT "    return 0;\n";
 		    print OUT "}\n\n";
 		}
 	    }
 	}
 
 	my $methodName = $hasGet{$className} eq '1' ? 'getInParents' : 'get';
-        print OUT "KJS::Value ${className}::$methodName(KJS::ExecState *exec, const KJS::UString &propertyName, const KJS::ObjectImp* bridge) const\n";
+        print OUT "Value ${printName}::$methodName(GET_METHOD_ARGS) const\n";
         print OUT "{\n";
 	my $paramsUsed = 0;
 	# Now look in prototype, if it exists
 	if ( defined $hasFunctions{$className} ) {
 	    # Prototype exists (because the class has functions)
-	    print OUT "    KJS::Object proto = " . $hasFunctions{$className} . "::self(exec);\n";
-	    print OUT "    if ( proto.hasProperty(exec,propertyName) ) {\n"; ## TODO get() directly
-	    print OUT "        return proto.get(exec,propertyName);\n";
-	    print OUT "    }\n";
+
+		# We use namespace declartions!
+		my $output = $hasFunctions{$className};
+		$output =~ s/KSVG:://;
+
+	    print OUT "    Object proto = " . $output . "::self(p1);\n";
+	    print OUT "    if(proto.hasProperty(p1,p2)) return proto.get(p1,p2);\n"; ## TODO get() directly
 	    $paramsUsed = 1;
 	}
 	foreach my $anc (@ancestorsWithGet) {
-	    print OUT "    if (${anc}::hasProperty(exec, propertyName))\n"; ## TODO get() directly
-	    print OUT "        return ${anc}::get(exec, propertyName, bridge);\n";
+		# We use namespace declartions!
+		my $printAnc = $anc;
+		$printAnc =~ s/KSVG:://;
+
+		print OUT "    if(${printAnc}::hasProperty(p1,p2)) return ${printAnc}::get(p1,p2,p3);\n"; ## TODO get() directly
 	    $paramsUsed = 2;
 	}
 
 	if ($paramsUsed == 0 ){
-	    print OUT "    Q_UNUSED(exec); Q_UNUSED(propertyName); Q_UNUSED(bridge);\n";
+	    print OUT "    Q_UNUSED(p1); Q_UNUSED(p2); Q_UNUSED(p3);\n";
 	} elsif ( $paramsUsed == 1 ) {
-	    print OUT "    Q_UNUSED(bridge);\n";
+	    print OUT "    Q_UNUSED(p3);\n";
 	}
-        print OUT "    return KJS::Undefined();\n";
+        print OUT "    return Undefined();\n";
         print OUT "}\n\n";
 
 	if ( $hasPut{$className} )
 	{
 	    if ( $hasPut{$className} eq '1' ) {
 		if ($hasHashTable{$className}) {
-		    print OUT "bool ${className}::put(KJS::ExecState *exec, const KJS::UString &propertyName, const KJS::Value &value, int attr)\n";
+		    print OUT "bool ${printName}::put(PUT_METHOD_ARGS)\n";
 		    print OUT "{\n";
-		    print OUT "    return lookupPut<${className}>(exec, propertyName, value, attr, &s_hashTable, this);\n";
+		    print OUT "    return lookupPut<${printName}>(p1,p2,p3,p4,&s_hashTable,this);\n";
 		    print OUT "}\n\n";
 		}
-		print OUT "bool ${className}::putInParents(KJS::ExecState *exec, const KJS::UString &propertyName, const KJS::Value &value, int attr)\n";
+		print OUT "bool ${printName}::putInParents(PUT_METHOD_ARGS)\n";
 	    } else { # forward put
-		print OUT "bool ${className}::put(KJS::ExecState *exec, const KJS::UString &propertyName, const KJS::Value &value, int attr)\n";
+		print OUT "bool ${printName}::put(PUT_METHOD_ARGS)\n";
 	    }
 	    print OUT "{\n";
 	    my $paramsUsed = 0;
 	    Iter::Ancestors( $classNode, $rootnode, undef, undef, sub {
 			     my $superClassName = join( "::", kdocAstUtil::heritage($_[0]) );
+
+				 # We use namespace declartions!
+				 my $printSuperClassName = $superClassName;
+				 $printSuperClassName =~ s/KSVG:://;
+
 			     if ( $superClassName ne '' ) { # happens with unknown parents
 				 if ( $hasPut{$superClassName} ) {
-				     print OUT "    if (${superClassName}::hasProperty(exec, propertyName)) {\n";
-				     print OUT "        ${superClassName}::put(exec, propertyName, value, attr);\n";
+				     print OUT "    if(${printSuperClassName}::hasProperty(p1,p2)) {\n";
+				     print OUT "        ${printSuperClassName}::put(p1,p2,p3,p4);\n";
 				     print OUT "        return true;\n";
 				     print OUT "    }\n";
 				     $paramsUsed=1;
@@ -426,23 +500,28 @@ sub writeInheritanceFile($) {
 			     }
 		    }, undef );
 	    if (!$paramsUsed){
-		print OUT "    Q_UNUSED(exec); Q_UNUSED(propertyName); Q_UNUSED(value); Q_UNUSED(attr);\n";
+		print OUT "    Q_UNUSED(p1); Q_UNUSED(p2); Q_UNUSED(p3); Q_UNUSED(p4);\n";
 	    }
 	    print OUT "    return false;\n";
 	    print OUT "}\n\n";
 	}
 
 	# Write prototype method
-	print OUT "KJS::Object ${className}::prototype(KJS::ExecState *exec) const\n";
+	print OUT "Object ${printName}::prototype(ExecState *p1) const\n";
 	print OUT "{\n";
 	if ( defined $hasFunctions{$className} ) {
+
+		# We use namespace declartions!
+		my $output = $hasFunctions{$className};
+		$output =~ s/KSVG:://;
+
 	    # Prototype exists (because the class has functions)
-	    print OUT "    if (exec) return " . $hasFunctions{$className} . "::self(exec);\n";
+	    print OUT "    if(p1) return " . $output . "::self(p1);\n";
 	} else {
 	    # Standard Object prototype
-	    print OUT "    if (exec) return exec->interpreter()->builtinObjectPrototype();\n";
+	    print OUT "    if(p1) return p1->interpreter()->builtinObjectPrototype();\n";
 	}
-	print OUT "    return KJS::Object::dynamicCast(KJS::Null());\n"; # hmm
+	print OUT "    return Object::dynamicCast(Null());\n"; # hmm
 
         print OUT "}\n\n";
 
@@ -452,16 +531,16 @@ sub writeInheritanceFile($) {
 		#print STDERR "Writing bridge() for $className...\n";
 		
 		# Write bridge method
-		print OUT "KJS::ObjectImp *${className}::bridge(KJS::ExecState *exec) const\n";
+		print OUT "ObjectImp *${printName}::bridge(ExecState *p1) const\n";
 		print OUT "{\n";
 		
 		if ($hasPut{$className})
 		{
-			print OUT "    return new KSVGRWBridge<${className}>(exec, const_cast<${className} *>(this));\n";
+			print OUT "    return new KSVGRWBridge<${printName}>(p1,const_cast<${printName} *>(this));\n";
 		}
 		else
 		{
-			print OUT "    return new KSVGBridge<${className}>(exec, const_cast<${className} *>(this));\n";
+			print OUT "    return new KSVGBridge<${printName}>(p1,const_cast<${printName} *>(this));\n";
 		}
 		
 		print OUT "}\n\n";
@@ -469,16 +548,16 @@ sub writeInheritanceFile($) {
 
 	if ($hasGet{$className}) {
 		# Write cache method
-		print OUT "KJS::Value ${className}::cache(KJS::ExecState *exec) const\n";
+		print OUT "Value ${printName}::cache(ExecState *p1) const\n";
 		print OUT "{\n";
 		
 		if ($hasPut{$className})
 		{
-			print OUT "    return KJS::Value(cacheDOMObject<${className}, KSVGRWBridge<${className}> >(exec, const_cast<${className} *>(this)));\n";
+			print OUT "    return KJS::Value(cacheDOMObject<${printName},KSVGRWBridge<${printName}> >(p1,const_cast<${printName} *>(this)));\n";
 		}
 		else
 		{
-			print OUT "    return KJS::Value(cacheDOMObject<${className}, KSVGBridge<${className}> >(exec, const_cast<${className} *>(this)));\n";
+			print OUT "    return KJS::Value(cacheDOMObject<${printName},KSVGBridge<${printName}> >(p1,const_cast<${printName} *>(this)));\n";
 		}
 		
 		print OUT "}\n\n";
